MailboxStore

Trait MailboxStore 

pub trait MailboxStore: Send + Sync {
    type Msg;
    type Task;
    type Error: Error + Send + Sync + 'static;

    // Required methods
    fn post(&self, msg: &Self::Msg) -> Result<(), Self::Error>;
    fn inbox(
        &self,
        team_id: &str,
        to: &str,
    ) -> Result<Vec<Self::Msg>, Self::Error>;
    fn claim(&self, message_id: Uuid) -> Result<bool, Self::Error>;
    fn consume(&self, message_id: Uuid) -> Result<(), Self::Error>;
    fn unclaim(&self, message_id: Uuid) -> Result<(), Self::Error>;
    fn task_create(&self, task: &Self::Task) -> Result<(), Self::Error>;
    fn task_update(
        &self,
        id: Uuid,
        state: MailboxTaskState,
        note: Option<&str>,
    ) -> Result<(), Self::Error>;
    fn task_list(&self, team_id: &str) -> Result<Vec<Self::Task>, Self::Error>;
}
The MailboxStore port: durable mailbox + task list.

Implementations MUST guarantee atomic claim semantics: at most one caller wins the race to claim a given message (i.e. Unread → Delivered is exclusive).

Required Associated Types

type Msg

The message type stored by this implementation.

type Task

The task type stored by this implementation.

type Error: Error + Send + Sync + 'static

The error type returned by store operations.

Required Methods

fn post(&self, msg: &Self::Msg) -> Result<(), Self::Error>

Post a message into the mailbox.

fn inbox(&self, team_id: &str, to: &str) -> Result<Vec<Self::Msg>, Self::Error>

Return all unread messages addressed to to in team_id.

fn claim(&self, message_id: Uuid) -> Result<bool, Self::Error>

Atomic claim: transition message state from Unread to Delivered.

Returns true iff this caller won the race (SQLite rowcount == 1).

fn consume(&self, message_id: Uuid) -> Result<(), Self::Error>

Mark a message as Consumed.

fn unclaim(&self, message_id: Uuid) -> Result<(), Self::Error>

Roll back a claim: transition message state from Delivered to Unread.

fn task_create(&self, task: &Self::Task) -> Result<(), Self::Error>

Insert a new task.

fn task_update( &self, id: Uuid, state: MailboxTaskState, note: Option<&str>, ) -> Result<(), Self::Error>

Advance a task’s state, optionally recording a note.

fn task_list(&self, team_id: &str) -> Result<Vec<Self::Task>, Self::Error>

Return all tasks for a team.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors